bl_info = {
    "name": "Camera2View",
    "author": "Marko Prpic Zets",
    "version": (1, 5, 1),
    "blender": (4, 2, 0),
    "location": "View3D > Sidebar > Camera2View",
    "description": "Creates a camera from the current view and keyframes it",
    "category": "3D View",
    "tags": ["Camera", "Animation", "3D View", "Tools"],
}

import bpy
from . import panel, operators, utils
from .utils import register_camera_resolution_props, unregister_camera_resolution_props, apply_per_camera_resolution

classes = (
    operators.VIEW3D_OT_CreateCamera,
    operators.VIEW3D_OT_KeyframeCamera,
    operators.VIEW3D_OT_NextCamera,
    operators.VIEW3D_OT_PrevCamera,
    operators.VIEW3D_OT_NextKeyframe,
    operators.VIEW3D_OT_PrevKeyframe,
    operators.VIEW3D_OT_KeyframeProperty,
    operators.VIEW3D_OT_ApplyResolution,
    operators.VIEW3D_OT_OpenVideoTutorials,
    operators.VIEW3D_OT_OpenSupport,
    panel.CAMERA2VIEW_PT_Panel,
)

def register():
    register_camera_resolution_props()
    for cls in classes:
        bpy.utils.register_class(cls)
    if apply_per_camera_resolution not in bpy.app.handlers.depsgraph_update_post:
        bpy.app.handlers.depsgraph_update_post.append(apply_per_camera_resolution)

def unregister():
    for cls in reversed(classes):
        bpy.utils.unregister_class(cls)
    unregister_camera_resolution_props()
    if apply_per_camera_resolution in bpy.app.handlers.depsgraph_update_post:
        bpy.app.handlers.depsgraph_update_post.remove(apply_per_camera_resolution)

if __name__ == "__main__":
    register()
