import bpy

class CAMERA2VIEW_PT_Panel(bpy.types.Panel):
    bl_label = "Camera2View"
    bl_idname = "CAMERA2VIEW_PT_panel"
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_category = 'Camera2View'

    def draw(self, context):
        layout = self.layout
        scene = context.scene
        cam = scene.camera

        if cam:
            layout.label(text=f"Active Camera: {cam.name}", icon='CAMERA_DATA')
        else:
            layout.label(text="No active camera", icon='ERROR')

        layout.operator("view3d.camera2view_create_camera", icon='CAMERA_DATA')
        layout.operator("view3d.camera2view_keyframe_camera", icon='KEY_HLT')

        # View Lock
        layout.separator()
        layout.label(text="View Lock", icon='LOCKED')

        area = next((a for a in context.window.screen.areas if a.type == 'VIEW_3D'), None)
        if area:
            space = next((s for s in area.spaces if s.type == 'VIEW_3D'), None)
            if space:
                layout.prop(space, "lock_object", text="Lock to Object")
                layout.prop(space, "use_cursor_lock", text="Lock to 3D Cursor")
                layout.prop(space, "lock_camera", text="Camera to View")

        layout.separator()
        layout.label(text="Camera Navigation", icon='CAMERA_DATA')
        layout.operator("view3d.camera2view_next_camera", icon='TRIA_RIGHT')
        layout.operator("view3d.camera2view_prev_camera", icon='TRIA_LEFT')

        layout.separator()
        layout.label(text="Keyframe Navigation", icon='KEY_HLT')
        layout.operator("view3d.camera2view_next_keyframe", icon='FORWARD')
        layout.operator("view3d.camera2view_prev_keyframe", icon='BACK')

        if cam and cam.type == 'CAMERA' and cam.name.startswith("Camera2View_"):
            cam_data = cam.data
            layout.separator()
            layout.label(text="Lens Properties", icon='OUTLINER_OB_CAMERA')

            def row_prop_key(prop, label):
                row = layout.row(align=True)
                row.prop(cam_data, prop, text=label)
                row.operator("view3d.camera2view_keyframe_property", text="Keyframe").property_name = prop

            row_prop_key("type", "Type")

            if cam_data.type == 'PERSP':
                row_prop_key("lens", "Focal Length")
                row_prop_key("lens_unit", "Lens Unit")
            elif cam_data.type == 'ORTHO':
                row_prop_key("ortho_scale", "Ortho Scale")

            row_prop_key("shift_x", "Shift X")
            row_prop_key("shift_y", "Shift Y")
            row_prop_key("clip_start", "Clip Start")
            row_prop_key("clip_end", "Clip End")

        # Render Format Properties
        layout.separator()
        layout.label(text="Format Properties", icon='RENDER_RESULT')

        render = scene.render
        layout.prop(render, "resolution_x", text="Resolution X")
        layout.prop(render, "resolution_y", text="Resolution Y")
        layout.prop(render, "resolution_percentage", text="Scale (%)")
        layout.prop(render, "pixel_aspect_x", text="Pixel Aspect X")
        layout.prop(render, "pixel_aspect_y", text="Pixel Aspect Y")
        
        # Custom Camera Resolution
        layout.separator()
        layout.label(text="Custom C2V Resolution", icon='MODIFIER')

        if cam and cam.type == 'CAMERA' and hasattr(cam.data, "per_res_enable"):
            cam_data = cam.data
            layout.prop(cam_data, "per_res_enable", text="Enable Custom Resolution")
            if cam_data.per_res_enable:
                layout.prop(cam_data, "per_res_x", text="Resolution X")
                layout.prop(cam_data, "per_res_y", text="Resolution Y")
                layout.operator("view3d.camera2view_apply_resolution", icon='CHECKMARK')

        # Resources Section
        layout.separator()
        layout.label(text="Resources:", icon='HELP')
        layout.operator("view3d.camera2view_open_video_tutorials", icon='PLAY', text="Video Tutorials")
        layout.operator("view3d.camera2view_open_support", icon='QUESTION', text="Get Support!")
